//**********************************************************************************
// Persistence Of Vision Ray tracer version 3.6.1c
// Plane curved line Curvature Scene File
// By S.Nishimura
//**********************************************************************************

global_settings { assumed_gamma 1.0 max_trace_level 5 }

camera { location -200*z look_at 0 angle 50 }

light_source { 40*y color rgb <1.0, 0.8, 0.6> parallel point_at z shadowless }

//**********************************************************************************
//create a TrueType text shape Tdisp parameter Fm=1/2(Center)
#macro Tdisp(Txt,Fm,Sc,Tr)
 #local Trns=Tr+<-Fm*strlen(Txt)*Sc/2,-Sc/3,0>;
 object { text { ttf "cyrvetic.ttf", Txt, 1, 0 }
  clipped_by { plane { z,1e-4 } } scale Sc translate Trns no_shadow }
#end
//**********************************************************************************
// 2th order differential equation (runge-kutta) Kappa_line
#macro Kappa_line(Lr,P0,Xmax,N,Fn)
 #local X=P0.x; #local Y=P0.y; #local Z=P0.z; #local H=(Xmax-P0.x)/N;
 #local i=0; #while(i<N+1)
  #local P1=<X,Y,0>; #if(i!=0) sphere { P1, Lr } #end
  #local V1=Dfunc(X,Y,Z,Fn);
  #local V2=Dfunc(X+H/2,Y+H*V1.y/2,Z+H*V1.z/2,Fn);
  #local V3=Dfunc(X+H/2,Y+H*V2.y/2,Z+H*V2.z/2,Fn);
  #local V4=Dfunc(X+H,Y+H*V3.y,Z+H*V3.z,Fn);
  #local Y=Y+(V1.y+2*V2.y+2*V3.y+V4.y)*H/6; #local Z=Z+(V1.z+2*V2.z+2*V3.z+V4.z)*H/6; #local X=X+H;
  #local P2=<X,Y,0>; #if(P1.x!=P2.x & P1.y!=P2.y) cylinder { P1, P2, Lr } #end
 #local i=i+1; #end
#end
//----------------------------------------------------------------------------------
#macro Dfunc(X,Y,Z,Fn) //y'=z,y''=K(1+z^2)^3/2
 #switch(Fn)
  #case( 1) #local Dy1=Z; #local K=0; #local Dy2=K*pow(1+pow(Z,2),3/2); #break //line y(-3)=Y,z(-3)=m
  #case( 2) #local Dy1=Z; #local K=1; #local Dy2=K*pow(1+pow(Z,2),3/2); #break //circle y(0)=-1,z(0)=0
  #case( 3) #local Dy1=Z; #local K=1/pow(cosh(X),2); #local Dy2=K*pow(1+pow(Z,2),3/2); #break //catenary y(0)=0,z(0)=0
 #end <X,Dy1,Dy2>
#end
//**********************************************************************************
// Higher order differential equation Differ_line
#macro Differ_line(Lr,Ys,Xmax,N,Odr,Fn)
 #local X0=Ys[0]; #local Row=5; #local T=array[Odr+1] #local K=array[Odr+1][Row]
 #local A=array[4]{ 0, 1/2, 1/2, 1 }
 #local K=array[Odr+1][Row]
 #local i=1; #while(i<Odr+1)
  #local j=0; #while(j<Row) #local K[i][j]=0; #local j=j+1; #end
 #local i=i+1; #end
 #local H=(Xmax-X0)/N;
 #local i=0; #while(i<N+1)
  #local Xp=X0; #local Yp=Ys[1]; #local P1=<Xp,Yp,0>;
  #local j=1; #while(j<=4)
   #local Ki=1; #while(Ki<Odr+1) #local T[Ki]=Ys[Ki]+A[j-1]*K[Ki][j-1]; #local Ki=Ki+1; #end
   #local Ki=1; #while(Ki<Odr+1) #local K[Ki][j]=H*D_func(X0+A[j-1]*H,T,0,Fn-1+Ki); #local Ki=Ki+1; #end   
  #local j=j+1; #end
  #local j=1; #while(j<Odr+1)
   #local Ys[j]=Ys[j]+(K[j][1]+2*K[j][2]+2*K[j][3]+K[j][4])/6;
  #local j=j+1; #end
  #local X0=X0+H;
  #local Xp=X0; #local Yp=Ys[1]; #local P2=<Xp,Yp,0>;
  cylinder { P1, P2, Lr } #if(i<N) sphere { P2, Lr } #end
 #local i=i+1; #end
#end
//----------------------------------------------------------------------------------
#macro D_func(X,Y,Z,Fn) //y'=z,y''=K(1+z^2)^3/2
 #switch(Fn)
  #case( 1) #local D=Y[2]; #break //line y(-3)=Y,z(-3)=m
  #case( 2) #local K=0; #local D=K*pow(1+pow(Y[2],2),3/2); #break
  #case( 3) #local D=Y[2]; #break //circle y(0)=-1,z(0)=0
  #case( 4) #local K=1; #local D=K*pow(1+pow(Y[2],2),3/2); #break
  #case( 5) #local D=Y[2]; #break //catenary y(0)=0,z(0)=0
  #case( 6) #local K=1/pow(cosh(X),2); #local D=K*pow(1+pow(Y[2],2),3/2); #break
 #end D
#end
//**********************************************************************************
background { color rgb <0.15, -0.001, 0.052> }
//**********************************************************************************
quadric{ <0,1,1>,<0,0,0>,<0,0,0>,-1 scale 1/4 pigment { color rgbt <1,1,0,0.5> } } //x
quadric{ <1,0,1>,<0,0,0>,<0,0,0>,-1 scale 1/4 pigment { color rgbt <1,1,0,0.5> } } //y
//**********************************************************************************
#local Square_seg = intersection { box{ <-3,-3,-1e-5>, <3,3,1e-5> } box { -1, 1 inverse } }
#local Trns0 = <0,56,-4/5>; #local Trns1 = <0,-54,-4/5>; #local Trns2 = <0,-63,-4/5>;
//**********************************************************************************
#local Pc = pigment { color rgb <0, 1.513, 0.983> }
#local Ps = pigment { color rgb <1.3, -0.02, 0.466> }
//----------------------------------------------------------------------------------
#local F0 = finish { ambient 0.3 reflection 0.1 phong 0.1 }
#local F1 = finish { ambient 0 diffuse 1 reflection 0.5 specular 0.6 phong 0.2 brilliance 1 }
#local F2 = finish { ambient 0.3 diffuse 1 reflection 1 specular 0.8 phong 0.5 brilliance 1 }
//----------------------------------------------------------------------------------
#local Lc = texture { pigment { color rgb <0.397, 1.277, 0.278> } finish { F0 } }
#local Tc = texture { pigment { Pc } finish { F0 } }
#local T1 = texture { pigment { color rgbt <0.7, 1.003, 0.897, 0.9> } finish { F1 } }
#local T2 = texture { pigment { color rgbt <1, 1, 1, 0.95> } finish { F2 } }
//**********************************************************************************
#local Fn=2; //2,3
#if(Fn>0)
 object { Square_seg pigment { Ps } scale <(sqrt(5)+1)/2,1,1>*50 translate -z*3/5 }
#end
#switch(Fn)
 #case(1)
  object { Tdisp("Straight line",1/2,10,Trns0+5*x) texture { Tc } } #local Sc=20;
  union { Kappa_line(1/(2*Sc),<-3,-3*tan(radians(30)),tan(radians(30))>,3.0,20,Fn) texture { Lc } scale Sc }
  union { Tdisp("y'=z,y''=K*(1+z^2)^(3/2) , K=0",0.44,8,Trns1)
          Tdisp("x=-3,y(x)=x*tan(pi/6),z(x)=tan(pi/6) , ( -3<x<3 )",0.42,7,Trns2) texture { Tc } }
 #break
 #case(2)
  object { Tdisp("Circle",1/2,10,Trns0) texture { Tc } } #local Sc=40;
  #local Graph = union { Kappa_line(1/(2*Sc),<0,-1,tan(radians(0))>,0.98,40,Fn) texture { Lc } scale Sc }
  object { Graph } object { Graph rotate 180*x }
  object { Graph rotate 180*y } object { Graph rotate <180,180> }
  union { Tdisp("y'=z,y''=K*(1+z^2)^(3/2) , K=1",0.45,8,Trns1)
          Tdisp("x=0,y(x)=-1,z(x)=0 , ( 0<x<1 )",0.42,7,Trns2) texture { Tc } }
  object { Tdisp("=",0,7,Trns2+<30,-3,0>) texture { Tc } }
 #break
 #case(3)
  object { Tdisp("Catenary",1/2,10,Trns0) texture { Tc } } #local Sc=40;
  #local Graph = union { Kappa_line(1/(2*Sc),<0,0,tan(radians(0))>,2,20,Fn) texture { Lc } scale Sc }
  object { Graph } object { Graph rotate 180*y }
  union { Tdisp("y'=z,y''=K*(1+z^2)^(3/2) , K=1/cosh(x)^2",0.47,8,Trns1)
          Tdisp("x=0,y(x)=0,z(x)=0 , ( 0<x<2 )",0.44,7,Trns2) texture { Tc } }
  object { Tdisp("=",0,7,Trns2+<27.25,-3,0>) texture { Tc } }
 #break
#end
//----------------------------------------------------------------------------------
#local Fn=0;
#if(Fn>0)
 object { Square_seg pigment { Ps } scale <(sqrt(5)+1)/2,1,1>*50 translate -z*3/5 }
#end
#switch(Fn)
 #case(1)
  object { Tdisp("Straight line",1/2,10,Trns0+5*x) texture { Tc } } #local Sc=20;
  #local Cd=array[2+1]{ -3, -3*tan(radians(30)), tan(radians(30)) }
  union { Differ_line(1/(2*Sc),Cd,3.0,20,2,Fn) texture { Lc } scale Sc }
  union { Tdisp("y'=z,y''=K*(1+z^2)^(3/2) , K=0",0.44,8,Trns1)
          Tdisp("x=-3,y(x)=x*tan(pi/6),z(x)=tan(pi/6) , ( -3<x<3 )",0.42,7,Trns2) texture { Tc } }
 #break
 #case(3)
  object { Tdisp("Circle",1/2,10,Trns0) texture { Tc } }
  #local Cd=array[3]{ 0, -1, tan(radians(0)) }
  #local Graph = union { Differ_line(1/60,Cd,0.98,40,2,3) texture { Lc } scale 30 }
  object { Graph } object { Graph rotate 180*x }
  object { Graph rotate 180*y } object { Graph rotate <180,180> }
  union { Tdisp("y'=z,y''=K*(1+z^2)^(3/2) , K=1",0.45,8,Trns1)
          Tdisp("x=0,y(x)=-1,z(x)=tan(0) , ( 0<x<1 )",0.42,7,Trns2-1.5*x) texture { Tc } }
 #break
 #case(5)
  object { Tdisp("Catenary",1/2,10,Trns0) texture { Tc } } #local Sc=40;
  #local Cd=array[2+1]{ 0, 0, tan(radians(0)) }
  #local Graph = union { Differ_line(1/(2*Sc),Cd,2,20,2,5) texture { Lc } scale Sc }
  object { Graph } object { Graph rotate 180*y }
  union { Tdisp("y'=z,y''=K*(1+z^2)^(3/2) , K=1/cosh(x)^2",0.47,8,Trns1)
          Tdisp("x=0,y(x)=0,z(x)=tan(0) , ( 0<x<2 )",0.44,7,Trns2) texture { Tc } }
 #break
#end
//**********************************************************************************