//**********************************************************************************
// Persistence Of Vision Ray tracer version 3.6.1c
// Plane curved line Lissajous Scene File
// By S.Nishimura
//**********************************************************************************

global_settings { assumed_gamma 1.0 max_trace_level 5 }

camera { location -200*z look_at 0 angle 50 }

light_source { 40*y color rgb <1.0,0.8,0.6> parallel point_at z }

//**********************************************************************************
//create a TrueType text shape Tdisp parameter Fm=1/2(Center)
#macro Tdisp(Txt,Fm,Sc,Tr)
 #local Trns=Tr+<-Fm*strlen(Txt)*Sc/2,-Sc/3,0>;
 object { text { ttf "cyrvetic.ttf", Txt, 1, 0 }
  clipped_by { plane { z,1e-4 } } scale Sc translate Trns no_shadow }
#end
//**********************************************************************************
 //xy-plane Lissajous parameter W1:<omega1,omega2,Alph1,Alph2>
#macro Lissajous(Lr,V1,W1)
 #local P1=<sin(W1.x*V1.x+W1.z),cos(W1.y*V1.x+W1.t)>;
 #local Tp=V1.x; #while(Tp<V1.y)
 #local P2=<sin(W1.x*(Tp+V1.z)+W1.z),cos(W1.y*(Tp+V1.z)+W1.t)>;
  cylinder { P1, P2, Lr } #if(Tp<V1.y-V1.z) sphere { P2, Lr } #end #local P1=P2;
 #local Tp=Tp+V1.z; #end
#end
//**********************************************************************************
//xy-plane Lissajous curved line parameter Typ:Lis=12,Pol=16
#macro Lissajous_line(Typ,Lr,V1,W1)
 #local Ctyp=asc(Typ)-(asc("A")-1);
 #switch(Ctyp)
  #case(12)
   #local P1=<sin(W1.x*V1.x+W1.z),cos(W1.y*V1.x+W1.t)>;
   #local Tp=V1.x; #while(Tp<V1.y)
   #local P2=<sin(W1.x*(Tp+V1.z)+W1.z),cos(W1.y*(Tp+V1.z)+W1.t)>;
    cylinder { P1, P2, Lr } #if(Tp<V1.y-V1.z) sphere { P2, Lr } #end #local P1=P2;
   #local Tp=Tp+V1.z; #end
  #break
  #else //variation(polar)
   #local P1=<cos(W1.x*V1.x+W1.z),cos(W1.y*V1.x+W1.t)>*<cos(V1.x),sin(V1.x)>;
   #local Tp=V1.x; #while(Tp<V1.y)
    #local P2=<cos(W1.x*(Tp+V1.z)+W1.z),cos(W1.y*(Tp+V1.z)+W1.t)>*<cos(Tp+V1.z),sin(Tp+V1.z)>;
    cylinder { P1, P2, Lr } #if(Tp<V1.y-V1.z) sphere { P2, Lr } #end #local P1=P2;
   #local Tp=Tp+V1.z; #end
  #break
 #end
#end // macro end
//**********************************************************************************
#macro Space_line4(Lr,V1,Fn)
#local Tp=V1.x; #while(Tp<V1.y)
 #local R1=Line_function(Tp+V1.z*0/3,Fn); #local P1=R1;
 #local R2=Line_function(Tp+V1.z*1/3,Fn);
 #local R3=Line_function(Tp+V1.z*2/3,Fn);
 #local R4=Line_function(Tp+V1.z*3/3,Fn);
 #local Ts=0; #local Te=1; #local Ta=1/(3*4);
 #local Ts=Ta; #while(Ts<Te)
  #local K1=1/2*(1-Ts)*(1-3*Ts)*(2-3*Ts);
  #local K2=9/2*Ts*(1-Ts)*(2-3*Ts);
  #local K3=-9/2*Ts*(1-Ts)*(1-3*Ts);
  #local K4=1/2*Ts*(1-3*Ts)*(2-3*Ts);
  #local P2=K1*R1+K2*R2+K3*R3+K4*R4; cylinder { P1, P2, Lr } sphere { P2, Lr } #local P1=P2;
 #local Ts=Ts+Ta; #end cylinder { P1, R4, Lr } #if(Tp<V1.y-V1.z) sphere { R4, Lr } #end
#local Tp=Tp+V1.z; #end
#end
//**********************************************************************************
#macro Line_function(Tp,Fn)
 #switch(Fn)
  #case(1) #local F=<sin(W.x*Tp+W.z),cos(W.y*Tp+W.t)>; #break
  #case(2) #local F=<cos(W.x*Tp+W.z),cos(W.y*Tp+W.t)>; #break
  #case(3) #local F=<sin(W.x*Tp+W.z),sin(W.y*Tp+W.t)>; #break
  #case(4) #local F=<cos(W.x*Tp+W.z),sin(W.y*Tp+W.t)>; #break
  #case(5) #local F=<cos(W.x*Tp+W.z)*cos(Tp),cos(W.y*Tp+W.t)*sin(Tp)>; #break //variation
 #end F
#end
//**********************************************************************************
background { color rgb <0.509, 1.05, 0.275> }
//**********************************************************************************
quadric{ <0,1,1>,<0,0,0>,<0,0,0>,-1 scale 1/4 pigment { color rgbt <1,1,0,0.5> } } //x
quadric{ <1,0,1>,<0,0,0>,<0,0,0>,-1 scale 1/4 pigment { color rgbt <1,1,0,0.5> } } //y
//**********************************************************************************
#local Square_seg = intersection { box{ <-3,-3,-1e-5>, <3,3,1e-5> } box { -1, 1 inverse } }
#local Trns0 = <0,57,-4/5>; #local Trns1 = <0,-56,-4/5>; #local Trns2 = <0,-65,-4/5>;
//**********************************************************************************
#local Sc = pigment { color rgb <0.886, 0.075, 1.237> }
//----------------------------------------------------------------------------------
#local F0 = finish { ambient 0.3 reflection 0.1 phong 0.5 }
#local F1 = finish { ambient 0.3 diffuse 1 reflection 1 specular 0.8 phong 0.5 brilliance 1 }
//----------------------------------------------------------------------------------
#local Lc = texture { pigment { color rgb <-0.6, 0.761, 0.284> } }
#local Tc = texture { pigment { color rgb <1.191, 1.093, 0.018> } finish { F0 } }
#local Tx = texture { pigment { color rgb <1.485, 0.583, 1.875> } finish { F1 } }
//**********************************************************************************
#local Fn=0;
#if(Fn>0)
 object { Tdisp("Lissajous",2.5,7,Trns0) texture { Tc } }
 object { Tdisp("Straight line",-0.1,8,Trns0) texture { Tx } }
 object { Square_seg pigment { Sc } scale <(1+sqrt(5))/2,1,1>*50 translate -z/4 }
 object { Tdisp("P(t)=<sin(W1*t+A1),cos(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
#end
#switch(Fn)
 #case( 1)
  union { Lissajous(1/80,<-2*pi,pi,1/40>,<radians(0),radians(30),0,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=0,W2=pi/6,A1=0,A2=0  ( -2*pi<t<pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case( 2)
  union { Lissajous(1/80,<-2*pi,pi,1/40>,<radians(0),radians(30),pi/6,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=0,W2=pi/6,A1=pi/6,A2=0  ( -2*pi<t<pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case( 3)
  union { Lissajous(1/80,<-pi,pi,1/40>,<radians(0),radians(180),pi/2,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=0,W2=pi,A1=pi/2,A2=0  ( -pi<t<pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case( 4)
  union { Lissajous(1/80,<-2*pi,2*pi,1/40>,<radians(30),radians(30),pi/2,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/6,W2=pi/6,A1=pi/2,A2=0  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case( 5)
  union { Lissajous(1/80,<-2*pi,2*pi,1/40>,<radians(30),radians(30),0,pi/2>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/6,W2=pi/6,A1=0,A2=pi/2  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
#end
//----------------------------------------------------------------------------------
#local Fn=0;
#if(Fn>0)
 object { Tdisp("Lissajous",2.5,7,Trns0) texture { Tc } }
 object { Square_seg pigment { Sc } scale <(1+sqrt(5))/2,1,1>*50 translate -z/4 }
 object { Tdisp("P(t)=<sin(W1*t+A1),cos(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
#end
#switch(Fn)
 #case( 6)
  object { Tdisp("Circle",-0.2,8,Trns0) texture { Tx } }
  union { Lissajous(1/80,<-2*pi,2*pi,1/40>,<radians(30),radians(30),0,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/6,W2=pi/6,A1=0,A2=0  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case( 7)
  object { Tdisp("Ellipse",-0.2,8,Trns0) texture { Tx } }
  union { Lissajous(1/80,<-2*pi,2*pi,1/40>,<radians(45),radians(45),pi/3,pi/2>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/4,W2=pi/4,A1=pi/3,A2=pi/2  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case( 8)
  object { Tdisp("Ellipse",-0.2,8,Trns0) texture { Tx } }
  union { Lissajous(1/80,<-2*pi,2*pi,1/40>,<radians(60),radians(60),pi/2,pi/6>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/3,W2=pi/3,A1=pi/2,A2=pi/6  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
#end
//----------------------------------------------------------------------------------
#local Fn=0;
#if(Fn>0)
 object { Tdisp("Lissajous",2.5,7,Trns0) texture { Tc } }
 object { Tdisp("Parabola",-0.2,8,Trns0) texture { Tx } }
 object { Square_seg pigment { Sc } scale <(1+sqrt(5))/2,1,1>*50 translate -z/4 }
 object { Tdisp("P(t)=<sin(W1*t+A1),cos(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
#end
#switch(Fn)
 #case( 9)
  union { Lissajous(1/80,<-pi,pi,1/40>,<radians(30),radians(30*2),0,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/6,W2=2*pi/6,A1=0,A2=0  ( -pi<t<pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case(10)
  union { Lissajous(1/80,<-2*pi,2*pi,1/40>,<radians(45),radians(45*2),pi/2,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/4,W2=2*pi/4,A1=pi/2,A2=0  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case(11)
  union { Lissajous(1/80,<-2*pi,2*pi,1/40>,<radians(45*2),radians(45),pi/2,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=2*pi/4,W2=pi/4,A1=pi/2,A2=0  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case(12)
  union { Lissajous(1/80,<-2*pi,2*pi,1/40>,<radians(60*2),radians(60),pi/2,pi/2>) texture { Lc } scale 40 }
  object { Tdisp("W1=2*pi/3,W2=pi/3,A1=pi/2,A2=pi/2  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
#end
//**********************************************************************************
#local Fn=22; //(21)22,(23),24~26,(27)
#if(Fn>0)
 object { Tdisp("Lissajous",2.5,7,Trns0) texture { Tc } }
 object { Square_seg pigment { Sc } scale <(1+sqrt(5))/2,1,1>*50 translate -z/4 }
#end
#switch(Fn)
 #case(21)
  #local W=<radians(30*2),radians(30),pi/12,pi/2>;
  union { Space_line4(1/160,<-2*pi,2*pi,1/40>,1) texture { Lc } scale 40 }
  object { Tdisp("P(t)=<sin(W1*t+A1),cos(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
  object { Tdisp("W1=2*pi/6,W2=pi/6,A1=pi/12,A2=pi/2  ( -2*pi<t<2*pi )",0.475,7,Trns2) texture { Tx } }
 #break
 #case(22)
  #local W=<radians(60*2),radians(60*3),0,pi/6>; #local Sc=40;
  union { Space_line4(1/(4*Sc),<-pi,pi,1/Sc>,2) texture { Lc } scale Sc }
  object { Tdisp("P(t)=<cos(W1*t+A1),cos(W2*t+A2)>",0.51,8,Trns1) texture { Tx } }
  object { Tdisp("W1=2*pi/3,W2=3*pi/3,A1=0,A2=pi/6  ( -pi<t<pi )",0.48,7,Trns2) texture { Tx } }
 #break
 #case(23)
  #local W=<radians(45),radians(45*3),0,pi/4>;
  union { Space_line4(1/160,<-2*pi,2*pi,1/40>,2) texture { Lc } scale 40 }
  object { Tdisp("P(t)=<cos(W1*t+A1),cos(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
  object { Tdisp("W1=pi/4,W2=3*pi/4,A1=0,A2=pi/4  ( -2*pi<t<2*pi )",0.47,7,Trns2) texture { Tx } }
 #break
 #case(24)
  #local W=<radians(30*7),radians(30*5),0,pi/6>;
  union { Space_line4(1/160,<-2*pi,2*pi,1/40>,4) texture { Lc } scale 40 }
  object { Tdisp("P(t)=<cos(W1*t+A1),sin(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
  object { Tdisp("W1=7*pi/6,W2=5*pi/6,A1=0,A2=pi/6  ( -2*pi<t<2*pi )",0.475,7,Trns2) texture { Tx } }
 #break
 #case(25)
  #local W=<radians(30*2),radians(30*7),0,pi/2>;
  union { Space_line4(1/160,<-2*pi,2*pi,1/40>,3) texture { Lc } scale 40 }
  object { Tdisp("P(t)=<sin(W1*t+A1),sin(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
  object { Tdisp("W1=2*pi/6,W2=7*pi/6,A1=0,A2=pi/2  ( -2*pi<t<2*pi )",0.48,7,Trns2) texture { Tx } }
 #break
 #case(26)
  #local W=<radians(30*6),radians(30*7),0,0>; #local Sc=40;
  union { Space_line4(1/(4*Sc),<-2*pi,2*pi,1/Sc>,1) texture { Lc } scale Sc }
  object { Tdisp("P(t)=<sin(W1*t+A1),cos(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
  object { Tdisp("W1=6*pi/6,W2=7*pi/6,A1=0,A2=0  ( -2*pi<t<2*pi )",0.48,7,Trns2) texture { Tx } }
 #break
 #case(27)
  #local W=<radians(60+15),radians(180),0,pi/2>;
  union { Space_line4(1/160,<-4*pi,4*pi,1/40>,1) texture { Lc } scale 40 }
  object { Tdisp("P(t)=<sin(W1*t+A1),cos(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
  object { Tdisp("W1=pi/3+pi/12,W2=3*pi/3,A1=0,A2=pi/2  ( -4*pi<t<4*pi )",0.48,6,Trns2) texture { Tx } }
 #break
#end
//**********************************************************************************
#local Fn=0;
#if(Fn>0)
 object { Tdisp("Lissajous",2.5,7,Trns0) texture { Tc } }
 object { Square_seg pigment { Sc } scale <(1+sqrt(5))/2,1,1>*50 translate -z/4 }
 object { Tdisp("P(t)=<sin(W1*t+A1),cos(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
#end
#switch(Fn)
 #case(31)
  union { Lissajous(1/160,<-2*pi,2*pi,1/40>,<radians(30*2),radians(30),0,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=2*pi/6,W2=pi/6,A1=0,A2=0  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case(32)
  union { Lissajous(1/160,<-2*pi,2*pi,1/40>,<radians(30),radians(30*2),0,pi/2>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/6,W2=2*pi/6,A1=0,A2=pi/2  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case(33)
  union { Lissajous(1/160,<-2*pi,2*pi,1/40>,<radians(30*2),radians(30),pi/12,pi/2>) texture { Lc } scale 40 }
  object { Tdisp("W1=2*pi/6,W2=pi/6,A1=pi/12,A2=pi/2  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case(34)
  union { Lissajous(1/160,<-2*pi,2*pi,1/40>,<radians(60*2),radians(60*3),pi/2,pi/6>) texture { Lc } scale 40 }
  object { Tdisp("W1=2*pi/3,W2=3*pi/3,A1=pi/2,A2=pi/6  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case(35)
  union { Lissajous(1/160,<-2*pi,2*pi,1/40>,<radians(45),radians(45*3),0,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/4,W2=3*pi/4,A1=0,A2=0  ( -2*pi<t<2*pi )",0.475,6,Trns2) texture { Tx } }
 #break
 #case(36)
  union { Lissajous(1/160,<-2*pi,2*pi,1/40>,<radians(45),radians(45*3),pi/2,pi/4>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/4,W2=3*pi/4,A1=pi/2,A2=pi/4  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
#end
//----------------------------------------------------------------------------------
#local Fn=0;
#if(Fn>0)
 object { Tdisp("Lissajous",2.5,7,Trns0) texture { Tc } }
 object { Square_seg pigment { Sc } scale <(1+sqrt(5))/2,1,1>*50 translate -z/4 }
 object { Tdisp("P(t)=<sin(W1*t+A1),cos(W2*t+A2)>",1/2,8,Trns1) texture { Tx } }
#end
#switch(Fn)
 #case(37)
  union { Lissajous(1/160,<-2*pi,2*pi,1/40>,<radians(30),radians(30*8),pi/2,pi/3>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/6,W2=8*pi/6,A1=pi/2,A2=pi/3  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case(38)
  union { Lissajous(1/160,<-4*pi,4*pi,1/40>,<radians(45),radians(45*3+15),0,pi/2>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/4,W2=3*pi/4+pi/12,A1=0,A2=pi/2  ( -4*pi<t<4*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case(39)
  union { Lissajous(1/160,<-2*pi,2*pi,1/40>,<radians(30*7),radians(30*5),pi/2,-pi/3>) texture { Lc } scale 40 }
  object { Tdisp("W1=7*pi/6,W2=5*pi/6,A1=pi/2,A2=-pi/3  ( -2*pi<t<2*pi )",0.47,6,Trns2) texture { Tx } }
 #break
 #case(40)
  union { Lissajous(1/160,<-2*pi,2*pi,1/40>,<radians(30*2),radians(30*7),0,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=2*pi/6,W2=7*pi/6,A1=0,A2=0  ( -2*pi<t<2*pi )",0.48,6,Trns2) texture { Tx } }
 #break
 #case(41)
  union { Lissajous(1/160,<-2*pi,2*pi,1/40>,<radians(30*6),radians(30*7),0,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=6*pi/6,W2=7*pi/6,A1=0,A2=0  ( -2*pi<t<2*pi )",0.48,6,Trns2) texture { Tx } }
 #break
 #case(42)
  union { Lissajous(1/160,<-4*pi,4*pi,1/40>,<radians(30*2+15),radians(30*6),0,pi/2>) texture { Lc } scale 40 }
  object { Tdisp("W1=2*pi/6+pi/12,W2=6*pi/6,A1=0,A2=pi/2  ( -4*pi<t<4*pi )",0.48,6,Trns2) texture { Tx } }
 #break
 #case(43)
  union { Lissajous(1/160,<-4*pi,4*pi,1/40>,<radians(30*6-15),radians(30*7),0,pi/2>) texture { Lc } scale 40 }
  object { Tdisp("W1=6*pi/6-pi/12,W2=7*pi/6,A1=0,A2=pi/2  ( -4*pi<t<4*pi )",0.48,6,Trns2) texture { Tx } }
 #break
#end
//**********************************************************************************
#local Fn=0;
#if(Fn>0)
 object { Tdisp("Lissajous variation",1.2,7,Trns0) texture { Tc } }
 object { Square_seg pigment { Sc } scale <(1+sqrt(5))/2,1,1>*50 translate -z/4 }
 object { Tdisp("P(t)=<cos(W1*t+A1)*cos(t),cos(W2*t+A2)*sin(t)>",0.48,7,Trns1) texture { Tx } }
#end
#switch(Fn)
 #case(51)
  union { Lissajous_line("Pol",1/80,<-pi,pi,1/20>,<radians(0),radians(180),0,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=0,W2=pi,A1=0,A2=0  ( -pi<t<pi )",0.48,6,Trns2) texture { Tx } }
 #break
 #case(52)
  union { Lissajous_line("Pol",1/80,<-2*pi,2*pi,1/20>,<radians(30),radians(30),0,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/6,W2=pi/6,A1=0,A2=0  ( -2*pi<t<2*pi )",0.48,6,Trns2) texture { Tx } }
 #break
 #case(53)
  union { Lissajous_line("Pol",1/80,<-4*pi,4*pi,1/20>,<radians(30),radians(90),pi/2,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=pi/6,W2=pi/2,A1=pi/2,A2=0  ( -4*pi<t<4*pi )",0.48,6,Trns2) texture { Tx } }
 #break
 #case(54)
  union { Lissajous_line("Pol",1/80,<-pi,pi,1/20>,<radians(30*4),radians(30),0,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=4*pi/6,W2=pi/6,A1=0,A2=0  ( -pi<t<pi )",0.48,6,Trns2) texture { Tx } }
 #break
 #case(55)
  union { Lissajous_line("Pol",1/80,<-2*pi,2*pi,1/20>,<radians(0),radians(45*3),pi/4,0>) texture { Lc } scale 40 }
  object { Tdisp("W1=0,W2=3*pi/4,A1=pi/4,A2=0  ( -2*pi<t<2*pi )",0.48,6,Trns2) texture { Tx } }
 #break
#end
//**********************************************************************************