//**********************************************************************************
// Persistence Of Vision Ray tracer version 3.6.1c
// Plane curved line Roalette Scene File
// By S.Nishimura
//**********************************************************************************

global_settings { assumed_gamma 1.0 max_trace_level 5 }

camera { location -200*z look_at 0 angle 50 }

light_source { 40*y color rgb 1 parallel point_at -z shadowless }

//**********************************************************************************
//create a TrueType text shape Tdisp parameter Fm=1/2(Center)
#macro Tdisp(Txt,Fm,Sc,Tr)
 #local Trns=Tr+<-Fm*strlen(Txt)*Sc/2,-Sc/3,0>;
 object { text { ttf "cyrvetic.ttf", Txt, 1, 0 }
  clipped_by { plane { z,1e-4 } } scale Sc translate Trns no_shadow }
#end
//**********************************************************************************
//xy-plane Roalette line parameter Typ:Cir=3,(Cyc=3,Epi=5,Hyp=8,Tor=20),Lin=12,(Pol=16,Var=22)
#macro Roal_line(Typ,Lr,V1,Vc)
 #local Ctyp=asc(Typ)-(asc("A")-1);
 #switch(Ctyp)
  #case( 3) //Epi(Vc.y>0),Hypo(Vc.y<0)
   #local R=Vc.x+Vc.y; #local Rr=Vc.y+Vc.z; #local K=R/Vc.y;
   #local P1=<R*cos(V1.x)-Rr*cos(K*V1.x),R*sin(V1.x)-Rr*sin(K*V1.x)>;
   #local Tp=V1.x; #while(Tp<V1.y)
    #local P2=<R*cos(Tp+V1.z)-Rr*cos(K*(Tp+V1.z)),R*sin(Tp+V1.z)-Rr*sin(K*(Tp+V1.z))>;
    cylinder { P1, P2, Lr } #if(Tp<V1.y-V1.z) sphere { P2, Lr } #end #local P1=P2;
   #local Tp=Tp+V1.z; #end   
  #break
  #case(12) //Inferior trocoid(Vc.z<0),Common cycloid(Vc.z=0),Superior trocoid(Vc.z>0)
   #local R=Vc.y+Vc.z;
   #local P1=<Vc.y*V1.x-R*sin(V1.x),Vc.y-R*cos(V1.x)+Vc.x>;
   #local Tp=V1.x; #while(Tp<V1.y)
    #local P2=<Vc.y*(Tp+V1.z)-R*sin(Tp+V1.z),Vc.y-R*cos(Tp+V1.z)+Vc.x>;
    cylinder { P1, P2, Lr } #if(Tp<V1.y-V1.z) sphere { P2, Lr } #end #local P1=P2;
   #local Tp=Tp+V1.z; #end   
  #break
  #case(16) //Variation(polar)
   #local R=Vc.y+Vc.z;
   #local P1=<Vc.y*V1.x-R*sin(V1.x),Vc.y-R*cos(V1.x)+Vc.x>*<cos(V1.x),sin(V1.x)>;
   #local Tp=V1.x; #while(Tp<V1.y) #local Tn=Tp+V1.z;
    #local P2=<Vc.y*(Tp+V1.z)-R*sin(Tp+V1.z),Vc.y-R*cos(Tp+V1.z)+Vc.x>*<cos(Tn),sin(Tn)>;
    cylinder { P1, P2, Lr } #if(Tp<V1.y-V1.z) sphere { P2, Lr } #end #local P1=P2;
   #local Tp=Tp+V1.z; #end
  #break
  #case(22) //Variation
   #local R=Vc.x+Vc.z;
   #local P1=<(Vc.x*V1.x-R*sin(V1.x))*exp(Vc.y+cos(V1.x)),(Vc.x-R*cos(V1.x))*cos(V1.x)>;
   #local Tp=V1.x; #while(Tp<V1.y) #local Tn=Tp+V1.z;
    #local P2=<(Vc.x*(Tn)-R*sin(Tn))*exp(Vc.y+cos(Tn)),(Vc.x-R*cos(Tn))*cos(Tn)>;
    cylinder { P1, P2, Lr } #if(Tp<V1.y-V1.z) sphere { P2, Lr } #end #local P1=P2;
   #local Tp=Tp+V1.z; #end   
  #break
  #else //Hypocycloid,Epicycloid,Hypotrocoid,Epitrocoid,(Circle)
   #local R=Vc.x+Vc.y; #local Rr=Vc.y+Vc.z; #local K=R/abs(Vc.y);
   #local P1=<R*cos(V1.x)-Rr*cos(K*V1.x),R*sin(V1.x)-abs(Rr)*sin(K*V1.x)>;
   #local Tp=V1.x; #while(Tp<V1.y)
    #local P2=<R*cos(Tp+V1.z)-Rr*cos(K*(Tp+V1.z)),R*sin(Tp+V1.z)-abs(Rr)*sin(K*(Tp+V1.z))>;
    cylinder { P1, P2, Lr } #if(Tp<V1.y-V1.z) sphere { P2, Lr } #end #local P1=P2;
   #local Tp=Tp+V1.z; #end   
  #break
 #end
#end // macro end
//**********************************************************************************
#macro Space_line4(Lr,V1,Fn)
#local Tp=V1.x; #while(Tp<V1.y)
 #local R1=Line_function(Tp+V1.z*0/3,Fn); #local P1=R1;
 #local R2=Line_function(Tp+V1.z*1/3,Fn);
 #local R3=Line_function(Tp+V1.z*2/3,Fn);
 #local R4=Line_function(Tp+V1.z*3/3,Fn);
 #local Ts=0; #local Te=1; #local Ta=1/(3*4);
 #local Ts=Ta; #while(Ts<Te)
  #local K1=1/2*(1-Ts)*(1-3*Ts)*(2-3*Ts);
  #local K2=9/2*Ts*(1-Ts)*(2-3*Ts);
  #local K3=-9/2*Ts*(1-Ts)*(1-3*Ts);
  #local K4=1/2*Ts*(1-3*Ts)*(2-3*Ts);
  #local P2=K1*R1+K2*R2+K3*R3+K4*R4; cylinder { P1, P2, Lr } sphere { P2, Lr } #local P1=P2;
 #local Ts=Ts+Ta; #end cylinder { P1, R4, Lr } #if(Tp<V1.y-V1.z) sphere { R4, Lr } #end
#local Tp=Tp+V1.z; #end
#end
//**********************************************************************************
#macro Line_function(Tp,Fn)
 #switch(Fn)
  //roalette
  #case( 1) #local F=<Vc.y*Tp-(Vc.y+Vc.z)*sin(Tp),Vc.y-(Vc.y+Vc.z)*cos(Tp)+Vc.x>; #break //cycloid & trocoid
  #case( 2) #local F=<(Vc.x+Vc.y)*cos(Tp)-(Vc.y+Vc.z)*cos(Tp*(Vc.x+Vc.y)/Vc.y),
                      (Vc.x+Vc.y)*sin(Tp)-(Vc.y+Vc.z)*sin(Tp*(Vc.x+Vc.y)/Vc.y)>; #break //Epi & Hypo
  //variation
  #case( 3) #local F=<(Vc.y*Tp-(Vc.y+Vc.z)*sin(Tp))*cos(Tp),(Vc.y-(Vc.y+Vc.z)*cos(Tp)+Vc.x)*sin(Tp)>; #break
  #case( 4) #local F=<(Vc.x*Tp-(Vc.x+Vc.z)*sin(Tp))*exp(Vc.y+cos(Tp)),(Vc.x-(Vc.x+Vc.z)*cos(Tp))*cos(Tp)>; #break
 #end F
#end
//**********************************************************************************
background { color rgb <0.25, 0.741, 0.794> }
//**********************************************************************************
quadric{ <0,1,1>,<0,0,0>,<0,0,0>,-1 scale 1/4 pigment { color rgbt <1,1,0,0.5> } } //x
quadric{ <1,0,1>,<0,0,0>,<0,0,0>,-1 scale 1/4 pigment { color rgbt <1,1,0,0.5> } } //y
//**********************************************************************************
#local Square_seg = object {  plane { z,0 } clipped_by { plane { -y,0 } } hollow }
#local Trns0 = <0,58,-1/2>; #local Trns1 = <0,-56-1,-1/2>; #local Trns2 = <0,-64-1,-1/2>;
//**********************************************************************************
#local Ps = pigment { color rgb <0.125, 1.351, 1.485> }
#local Pc = pigment { color rgb <1.857, 0.463, 1.515> }
//----------------------------------------------------------------------------------
#local F0 = finish { specular 0.1 reflection 0.1 }
#local F2 = finish { ambient 0.3 diffuse 1 reflection 1 specular 0.8 phong 0.5 brilliance 1 }
#local F3 = finish { metallic
       ambient 0.2 diffuse 0.35 specular 0.6 roughness 0.01 reflection 0.45 brilliance 0.5 }
//----------------------------------------------------------------------------------
#local Lc = texture { pigment { color rgb <-0.393, 0.484, 0.294> } finish { F0 } }
#local Tc = texture { pigment { color rgb <0.914, 1.048, 0.1> } finish { F2 } }
#local Tx = texture { pigment { color rgb <0.25, 0.741, 0.794> } finish { F3 } }
//**********************************************************************************
#local Fn=0;
#if(Fn>0)
 object { Square_seg texture { Tx } translate <0,54,-2/5> }
 object { Tdisp("Roalette",0,7,Trns0+55*x) texture { Lc } }
 object { Square_seg texture { Tx } translate <0,52.5,-2/5> rotate 180*z }
#end
#switch(Fn)
 #case( 1)
  object { Tdisp("Inferior trochoid",1,10,<0,60,-1/2>) texture { Pc } }
  #local Vc=<0,1,-1/2>;
  union { Space_line4(1/40,<-3*pi,3*pi,1/10>,Fn) texture { Lc } scale 10 }
  object { Tdisp("P(t)=<r*t-(r+d)*sin(t),r-(r+d)*cos(t)+L>",0.44,8,Trns1) texture { Pc } }
  object { Tdisp("L=0,r=1,d=-1/2 , ( -3*pi<t<3*pi )",0.46,7,Trns2) texture { Pc } }
 #break
 #case( 2)
  object { Tdisp("Epicycloid",1,10,<-25,60,-1/2>) texture { Pc } }
  #local Vc=<1,1/3,0>; #local Sc=26;
  union { Space_line4(1/(4*Sc),<-pi,pi,2/Sc>,Fn) texture { Lc } scale Sc }
  object { Tdisp("x(t)=(R+r)*cos(t)-(r+d)*cos(t*(R+r)/r)",0.425,7,Trns1+9*y) texture { Pc } }
  object { Tdisp("y(t)=(R+r)*sin(t)-(r+d)*sin(t*(R+r)/r)",0.425,7,Trns1) texture { Pc } }
  object { Tdisp("R=1,r=1/3,d=0 , ( -pi<t<pi )",0.46,7,Trns2) texture { Pc } }
 #break
 #case( 3)
  object { Tdisp("Variation",1,10,<-35,60,-1/2>) texture { Pc } }
  #local Vc=<1,1/2,-1/2>;
  union { Space_line4(1/40,<-6*pi,6*pi,1/10>,Fn) texture { Lc } scale 10 }
  object { Tdisp("P(t)=<(r*t-(r+d)*sin(t))*cos(t),(r-(r+d)*cos(t)+L)*sin(t)>",0.41,7,Trns1) texture { Pc } }
  object { Tdisp("L=1,r=1/2,d=-1/2 , ( -6*pi<t<6*pi )",1/2,7,Trns2+6*x) texture { Pc } }
 #break
 #case( 4)
  object { Tdisp("Variation",1,10,<-35,60,-1/2>) texture { Pc } }
  #local Vc=<-1/2,-1/2,-2>; #local Sc=14;
  union { Space_line4(1/(4*Sc),<-3*pi,3*pi,2/Sc>,Fn) texture { Lc } scale Sc }
  object { Tdisp("P(t)=<(A*t-(A+C)*sin(t))*exp(B+cos(t)),(A-(A+C)*cos(t))*cos(t)>",0.44,6,Trns1) texture { Pc } }
  object { Tdisp("A=-1/2,B=-1/2,C=-2 , ( -3*pi<t<3*pi )",1/2,7,Trns2+5*x) texture { Pc } }
 #break
#end
//**********************************************************************************
#local Fn=11; //11~13
#if(Fn>0)
 object { Square_seg pigment { Ps } translate <0,50,-2/5> }
 object { Tdisp("Roalette",2.9,7,Trns0) texture { Tx } }
 object { Tdisp("P(t)=<r*t-(r+d)*sin(t),r-(r+d)*cos(t)+L>",0.44,8,Trns1) texture { Tc } }
 object { Square_seg pigment { Pc } translate <0,50,-2/5> rotate 180*z }
#end
#switch(Fn)
 #case(11)
  object { Tdisp("   Inferior trochoid",0,8,Trns0) texture { Tc } }
  union { Roal_line("Line",1/40,<-3*pi,3*pi,1/10>,<0,1,-1/2>) texture { Lc } scale 10 }
  object { Tdisp("L=0,r=1,d=-1/2 , ( -3*pi<t<3*pi )",0.46,7,Trns2) texture { Tc } }
 #break
 #case(12)
  object { Tdisp("   Common cycloid",0,8,Trns0) texture { Tc } }
  union { Roal_line("Line",1/40,<-3*pi,3*pi,1/10>,<0,1,0>) texture { Lc } scale 10 }
  object { Tdisp("L=0,r=1,d=0 , ( -3*pi<t<3*pi )",0.46,7,Trns2) texture { Tc } }
 #break
 #case(13)
  object { Tdisp("   Superior trochoid",0,8,Trns0) texture { Tc } }
  union { Roal_line("Line",1/40,<-3*pi,3*pi,1/10>,<0,1,1/2>) texture { Lc } scale 10 }
  object { Tdisp("L=0,r=1,d=1/2 , ( -3*pi<t<3*pi )",0.46,7,Trns2) texture { Tc } }
 #break
#end
//----------------------------------------------------------------------------------
#local Fn=0; //21~25
#if(Fn>0)
 object { Square_seg pigment { Ps } translate <0,50,-2/5> }
 //object { Tdisp("Roalette",0,6,Trns0+60*x-12*y) pigment { Pc } }
 object { Tdisp("x(t)=(R+r)*cos(t)-(r+d)*cos(t*(R+r)/r)",0.425,7,Trns1+9*y) texture { Tc } }
 object { Tdisp("y(t)=(R+r)*sin(t)-(r+d)*sin(t*(R+r)/r)",0.425,7,Trns1) texture { Tc } }
 object { Square_seg pigment { Pc } translate <0,50-7,-2/5> rotate 180*z }
#end
#switch(Fn)
 #case(21)
  object { Tdisp("Epicycloid",2.3,7,Trns0) texture { Tx } } #local Sc=16;
  object { Tdisp("   Cardioid",0,8,Trns0) texture { Tc } }
  //union { Roal_line("Epi",1/(4*Sc),<-pi,pi,1/Sc>,<1,1,0>) texture { Lc } scale Sc }
  union { Roal_line("Circle",1/(4*Sc),<-pi,pi,1/Sc>,<1,1,0>) texture { Lc } scale Sc }
  object { Tdisp("R=1,r=1,d=0 , ( -pi<t<pi )",0.46,7,Trns2) texture { Tc } }
 #break
 #case(22)
  object { Tdisp("Epicycloid",2.1,7,Trns0) texture { Tx } } #local Sc=20;
  object { Tdisp("   Nephroid",0,8,Trns0) texture { Tc } }
  //union { Roal_line("Epi",1/(4*Sc),<-pi,pi,1/Sc>,<1,1/2,0>) texture { Lc } scale Sc }
  union { Roal_line("Circle",1/(4*Sc),<-pi,pi,1/Sc>,<1,1/2,0>) texture { Lc } scale Sc }
  object { Tdisp("R=1,r=1/2,d=0 , ( -pi<t<pi )",0.46,7,Trns2) texture { Tc } }
 #break
 #case(23)
  object { Tdisp("Hypocycloid",2.1,7,Trns0) texture { Tx } } #local Sc=45;
  object { Tdisp("   Deltoid",0,8,Trns0) texture { Tc } }
  //union { Roal_line("Hypo",1/(4*Sc),<-pi,pi,1/Sc>,<1,-1/3,0>) texture { Lc } scale Sc }
  union { Roal_line("Circle",1/(4*Sc),<-pi,pi,1/Sc>,<1,-1/3,0>) texture { Lc } scale Sc }
  object { Tdisp("R=1,r=-1/3,d=0 , ( -pi<t<pi )",0.46,7,Trns2) texture { Tc } }
 #break
 #case(24)
  object { Tdisp("Hypocycloid",2.1,7,Trns0) texture { Tx } } #local Sc=40;
  object { Tdisp("   Asteroid",0,8,Trns0) texture { Tc } }
  //union { Roal_line("Hypo",1/(4*Sc),<-pi,pi,1/Sc>,<1,-1/4,0>) texture { Lc } scale Sc }
  union { Roal_line("Circle",1/(4*Sc),<-pi,pi,1/Sc>,<1,-1/4,0>) texture { Lc } scale Sc }
  object { Tdisp("R=1,r=-1/4,d=0 , ( -pi<t<pi )",0.46,7,Trns2) texture { Tc } }
 #break
 #case(25)
  object { Tdisp("Superior hypotrochoid",1.1,7,Trns0) texture { Tx } } #local Sc=28;
  //object { Tdisp("   Four-leaf",0,8,Trns0) texture { Tc } }
  object { Tdisp("   Rose of 4 leaves",0,8,Trns0) texture { Tc } }
  //union { Roal_line("Tro",1/(4*Sc),<-pi,pi,1/Sc>,<1,-1/4,-1/2>) texture { Lc } scale Sc }
  union { Roal_line("Circle",1/(4*Sc),<-pi,pi,1/Sc>,<1,-1/4,-1/2>) texture { Lc } scale Sc }
  object { Tdisp("R=1,r=-1/4,d=-1/2 , ( -pi<t<pi )",0.46,7,Trns2) texture { Tc } }
 #break
#end
//----------------------------------------------------------------------------------
#local Fn=0;
#if(Fn>0)
 object { Square_seg pigment { Ps } translate <0,48,-1/5> }
 object { Tdisp("Roalette",2.9,7,Trns0) texture { Tx } }
 object { Tdisp("Variation",0,8,Trns0+48*x) texture { Tc } }
 object { Square_seg pigment { Pc } translate <0,48,-1/5> rotate 180*z }
#end
#switch(Fn)
 #case(31)
  object { Tdisp("P(t)=<(r*t-(r+d)*sin(t))*cos(t),(r-(r+d)*cos(t)+L)*sin(t)>",0.41,7,Trns1) texture { Tc } }
  union { Roal_line("Pol",1/40,<-6*pi,6*pi,1/10>,<1,1/2,-1/2>) texture { Lc } scale 10 }
  object { Tdisp("L=1,r=1/2,d=-1/2 , ( -6*pi<t<6*pi )",1/2,7,Trns2+6*x) texture { Tc } }
 #break
 #case(32)
  object { Tdisp("P(t)=<(A*t-(A+C)*sin(t))*exp(B+cos(t)),(A-(A+C)*cos(t))*cos(t)>",0.44,6,Trns1) texture { Tc } }
  union { Roal_line("Var",1/40,<-3*pi,3*pi,1/10>,<-1/2,-1/2,-2>) texture { Lc } scale 10 }
  object { Tdisp("A=-1/2,B=-1/2,C=-2 , ( -3*pi<t<3*pi )",1/2,7,Trns2+5*x) texture { Tc } }
 #break
#end
//**********************************************************************************